@@ -3,4 +3,4 @@ from .utils.function import f
 print('Welcome to Numerica!')
 
 # Test
-print(f(2, [5, -6, 1], 1)(5) == 0)
\ No newline at end of file
+# ...
\ No newline at end of file
