@@ -1,17 +1,19 @@
 import math
+from ...utils.function import parse_f
 from ...utils.math import haveSameSign
 
-def bisection(fn, epsilon=0.1, a=-10, b=10):
+@parse_f()
+def bisection(fx, epsilon=0.1, a=-10, b=10):
   prevC = math.inf # infinity
 
   while True:
     c = (a + b) / 2
-    fnc = fn(c)
+    fnc = fx(c)
 
     if (fnc == 0):
       return c
 
-    fna = fn(a)
+    fna = fx(a)
 
     if (fnc == 0):
       return c
