@@ -1,21 +1,23 @@
 import math
+from ...utils.function import parse_f
 from ...utils.math import haveSameSign
 
-def regulafalsi(fn, epsilon=0.1, a=-10, b=10):
+@parse_f()
+def regulafalsi(fx, epsilon=0.1, a=-10, b=10):
   prevC = math.inf # infinity
 
-  if (fn(a) == 0):
+  if (fx(a) == 0):
     return a
 
-  if (fn(b) == 0):
+  if (fx(b) == 0):
     return b
 
   while True:
-    fna = fn(a)
-    fnb = fn(b)
+    fna = fx(a)
+    fnb = fx(b)
 
     c = ((fna * b) - (fnb * a)) / (fna - fnb)
-    fnc = fn(c)
+    fnc = fx(c)
 
     if (fnc == 0):
       return c
