@@ -1,12 +1,14 @@
+from ...utils.function import parse_f
 from ...utils.math import haveSameSign
 
-def secant(fn, epsilon=0.1, x0=-10, x1=10):
+@parse_f()
+def secant(fx, epsilon=0.1, x0=-10, x1=10):
   while True:
-    y0 = fn(x0)
-    y1 = fn(x1)
+    y0 = fx(x0)
+    y1 = fx(x1)
 
     x2 = (x0 - (((x1-x0)/(y1 - y0)) * y0))
-    y2 = fn(x2)
+    y2 = fx(x2)
 
     if (y2 == 0):
       return x2
